import java.awt.*;
import javax.swing.*;

public class Animator1 extends JComponent implements Runnable
{
	private final int	  refresh_rate;
	private final Image[] frames;
	private		  int	  current_frame = 0;
	private		  Thread  driver;
	//------------------------------------------------------------------
	public Animator1( Image[] frames, int refresh_rate )
											throws InterruptedException
	{
		this.frames 	  = frames;
		this.refresh_rate = refresh_rate;

		MediaTracker tracker = new MediaTracker(this);	// wait for all
		for( int i = 0; i < frames.length; ++i )		// images to 
			tracker.addImage( frames[i], 0 );			// load
		tracker.waitForAll();
	}
	//------------------------------------------------------------------
	public void start()
	{	driver = new Thread( this );	//#newthread
		driver.start();
	}
	//------------------------------------------------------------------
	public void stop()
	{	driver.interrupt();
	}
	//------------------------------------------------------------------
	public Dimension getPreferredSize()
	{	return new Dimension(	frames[0].getWidth(this),
								frames[0].getHeight(this) );
	}
	//------------------------------------------------------------------
	public void paint( Graphics g )
	{	g.drawImage( frames[ current_frame ], 0, 0,
						getBounds().width, getBounds().height, this );
	}
	//------------------------------------------------------------------
 	public void run()
	{	try
		{	while( !Thread.interrupted() )
			{
				Thread.currentThread().sleep( refresh_rate );

				++current_frame;
				current_frame %= frames.length;

				Animator1.this.repaint();	//#repaint
			}
		}
		catch( InterruptedException e ){/*terminate thread by returning*/}
	}
	//==================================================================
	public static class Test extends JFrame
	{
		static public void main( String[] s ) throws Exception
		{
			Toolkit	kit		= Toolkit.getDefaultToolkit();
			Image[] images	= new Image[]
			{
				kit.getImage("5.images/Juggler0.gif"),
				kit.getImage("5.images/Juggler1.gif"),
				kit.getImage("5.images/Juggler2.gif"),
				kit.getImage("5.images/Juggler3.gif"),
				kit.getImage("5.images/Juggler4.gif") 
			};

			Animator1 animator = new Animator1( images, 100 );

			JFrame frame = new Test();
			frame.getContentPane().add( animator );
			frame.pack();
			frame.show();

			animator.start();
			Thread.currentThread().sleep( 5 * 1000 );
			animator.stop();
			System.exit(0);
		}
	}
}
